@@ -105,9 +105,10 @@ def create_vm(access_token, subscription_id, resource_group, vm_name, vm_size, p
 
 
 def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_size, capacity,
-                publisher, offer, sku, version, subnet_id, be_pool_id, lb_pool_id, location,
-                storage_type='Standard_LRS', username='azure', password=None, public_key=None,
-                overprovision=True, upgrade_policy='Manual', public_ip_per_vm=False):
+                publisher, offer, sku, version, subnet_id, location, be_pool_id=None,
+                lb_pool_id=None, storage_type='Standard_LRS', username='azure', password=None,
+                public_key=None, overprovision=True, upgrade_policy='Manual',
+                public_ip_per_vm=False):
     '''Create virtual machine scale set.
 
     Args:
@@ -122,9 +123,9 @@ def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_siz
         sku (str): VM image sku. E.g. '2016-Datacenter'.
         version (str): VM image version. E.g. 'latest'.
         subnet_id (str): Resource id of a subnet.
+        location (str): Azure data center location. E.g. westus.
         be_pool_id (str): Resource id of a backend NAT pool.
         lb_pool_id (str): Resource id of a load balancer pool.
-        location (str): Azure data center location. E.g. westus.
         storage_type (str): Optional storage type. Default 'Standard_LRS'.
         username (str): Optional user name. Default is 'azure'.
         password (str): Optional password. Default is None (not required if using public_key).
@@ -135,9 +136,6 @@ def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_siz
             Default 'Manual'.
         public_ip_per_vm (bool): Optional. Set public IP per VM. Default False.
 
-    To do:
-        Make the LB pool arguments optional.
-
     Returns:
         HTTP response. JSON body of the virtual machine scale set properties.
     '''
@@ -177,8 +175,10 @@ def create_vmss(access_token, subscription_id, resource_group, vmss_name, vm_siz
     nic = {'name': vmss_name}
     ip_config = {'name': vmss_name}
     ip_properties = {'subnet': {'id': subnet_id}}
-    ip_properties['loadBalancerBackendAddressPools'] = [{'id': be_pool_id}]
-    ip_properties['loadBalancerInboundNatPools'] = [{'id': lb_pool_id}]
+    if be_pool_id is not None:
+        ip_properties['loadBalancerBackendAddressPools'] = [{'id': be_pool_id}]
+    if lb_pool_id is not None:
+        ip_properties['loadBalancerInboundNatPools'] = [{'id': lb_pool_id}]
     if public_ip_per_vm is True:
         ip_properties['publicIpAddressConfiguration'] = {
             'name': 'pubip', 'properties': {'idleTimeoutInMinutes': 15}}
@@ -539,7 +539,7 @@ def get_vmss_vm_nics(access_token, subscription_id, resource_group, vmss_name, i
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
                         '/virtualMachines/', str(instance_id),
-                        '/networkInterfaces?api-version=', NETWORK_API])
+                        '/networkInterfaces?api-version=', COMP_API])
     return do_get(endpoint, access_token)
 
 
@@ -839,6 +839,56 @@ def poweroff_vmss_vms(access_token, subscription_id, resource_group, vmss_name,
     return do_post(endpoint, body, access_token)
 
 
+def put_vmss(access_token, subscription_id, resource_group, vmss_name, vmss_body):
+    '''Put VMSS body.
+
+    Can be used to create or update a scale set.
+    E.g. call get_vmss(), make changes to the body, call put_vmss().
+
+    Args:
+        access_token (str): A valid Azure authentication token.
+        subscription_id (str): Azure subscription id.
+        resource_group (str): Azure resource group name.
+        vmss_name (str): Name of the new scale set.
+        vmss_body (dictionary): Body containining 
+
+    Returns:
+        HTTP response. JSON body of the virtual machine scale set properties.
+    '''
+    endpoint = ''.join([get_rm_endpoint(),
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
+                        '?api-version=', COMP_API])
+    body = json.dumps(vmss_body)
+    return do_put(endpoint, body, access_token)
+
+
+def put_vmss_vm(access_token, subscription_id, resource_group, vmss_name, vm_id, vm_body):
+    '''Update a VMSS VM. E.g. add/remove a data disk from a specifc VM in a scale set (preview).
+       Note: Only currently enabled for Azure Canary regions.
+
+    Args:
+        access_token (str): A valid Azure authentication token.
+        subscription_id (str): Azure subscription id.
+        resource_group (str): Azure resource group name.
+        vmss_name (str): Name of the new scale set.
+        vm_id (int): VM ID of VM to update
+        vmss_body (dictionary): Body containining 
+
+    Returns:
+        HTTP response. JSON body of the virtual machine scale set VM properties.
+    '''
+    endpoint = ''.join([get_rm_endpoint(),
+                        '/subscriptions/', subscription_id,
+                        '/resourceGroups/', resource_group,
+                        '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
+                        '/virtualMachines/', str(vm_id),
+                        '?api-version=', COMP_API])
+    body = json.dumps(vm_body)
+    return do_put(endpoint, body, access_token)
+
+
 def reimage_vmss_vms(access_token, subscription_id, resource_group, vmss_name, instance_ids):
     '''Drive is reset, temp drive is not).
 
@@ -926,7 +976,7 @@ def restart_vmss_vms(access_token, subscription_id, resource_group, vmss_name, i
     return do_post(endpoint, body, access_token)
 
 
-def scale_vmss(access_token, subscription_id, resource_group, vmss_name, size, tier, capacity):
+def scale_vmss(access_token, subscription_id, resource_group, vmss_name, capacity):
     '''Change the instance count of an existing VM Scale Set.
 
     Args:
@@ -934,8 +984,6 @@ def scale_vmss(access_token, subscription_id, resource_group, vmss_name, size, t
         subscription_id (str): Azure subscription id.
         resource_group (str): Azure resource group name.
         vmss_name (str): Name of the virtual machine scale set.
-        size (str): VM size. E.g. 'Standard_D1_v2'.
-        tier (str): VM tier. E.g. 'Standard'.
         capacity (int): New number of VMs.
     Returns:
         HTTP response.
@@ -945,8 +993,7 @@ def scale_vmss(access_token, subscription_id, resource_group, vmss_name, size, t
                         '/resourceGroups/', resource_group,
                         '/providers/Microsoft.Compute/virtualMachineScaleSets/', vmss_name,
                         '?api-version=', COMP_API])
-    body = '{"sku":{ "name":"' + size + '", "tier":"' + \
-        tier + '", "capacity":"' + str(capacity) + '"}}'
+    body = '{"sku":{"capacity":"' + str(capacity) + '"}}'
     return do_patch(endpoint, body, access_token)
 
 
